==> org.eclipse.mylyn.jira.core.source_3.1.1.v20090411-0400-e3x.jar: org/eclipse/mylyn/internal/jira/core/IJiraConstants.java <==
/*******************************************************************************
 * Copyright (c) 2004, 2008 Tasktop Technologies and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Tasktop Technologies - initial API and implementation
 *******************************************************************************/

package org.eclipse.mylyn.internal.jira.core;

public class IJiraConstants {

	public static final String ATTRIBUTE_TYPE = "attribute.jira.type"; //$NON-NLS-1$

	public static final String ATTRIBUTE_ISSUE_PARENT_KEY = "attribute.jira.issue_parent_key"; //$NON-NLS-1$

	public static final String ATTRIBUTE_ISSUE_PARENT_ID = "attribute.jira.issue_parent_id"; //$NON-NLS-1$

	public static final String ATTRIBUTE_ENVIRONMENT = "attribute.jira.environment"; //$NON-NLS-1$

	public static final String ATTRIBUTE_COMPONENTS = "attribute.jira.components"; //$NON-NLS-1$

	public static final String ATTRIBUTE_FIXVERSIONS = "attribute.jira.fixversions"; //$NON-NLS-1$

	public static final String ATTRIBUTE_AFFECTSVERSIONS = "attribute.jira.affectsversions"; //$NON-NLS-1$

	public static final String ATTRIBUTE_ESTIMATE = "attribute.jira.estimate"; //$NON-NLS-1$

	public static final String ATTRIBUTE_INITIAL_ESTIMATE = "attribute.jira.initialestimate"; //$NON-NLS-1$

	public static final String ATTRIBUTE_ACTUAL = "attribute.jira.actual"; //$NON-NLS-1$

	public static final String ATTRIBUTE_DUE_DATE = "attribute.jira.due"; //$NON-NLS-1$

	public static final String ATTRIBUTE_SUBTASK_IDS = "attribute.jira.subtask_ids"; //$NON-NLS-1$

	public static final String ATTRIBUTE_SUBTASK_KEYS = "attribute.jira.subtask_keys"; //$NON-NLS-1$

	public static final String ATTRIBUTE_CUSTOM_PREFIX = "attribute.jira.custom::"; //$NON-NLS-1$

	public static final String ATTRIBUTE_LINK_PREFIX = "attribute.jira.link::"; //$NON-NLS-1$

	public static final String ATTRIBUTE_SECURITY_LEVEL = "attribute.jira.security"; //$NON-NLS-1$

	public static final String ATTRIBUTE_READ_ONLY = "attribute.jira.read-only"; //$NON-NLS-1$

	public static final String ATTRIBUTE_WORKLOG_NOT_SUPPORTED = "attribute.jira.worklog-not-supported"; //$NON-NLS-1$

	public static final String JIRA_DATE_FORMAT = "dd MMM yyyy HH:mm:ss z"; //$NON-NLS-1$

	public static final String META_TYPE = "type"; //$NON-NLS-1$

	public static final String ATTRIBUTE_LINKED_IDS = "attribute.jira.link_ids"; //$NON-NLS-1$

	public static final String META_SUB_TASK_TYPE = "isSubtaskType"; //$NON-NLS-1$

	public static final String JIRA_TOOLKIT_PREFIX = "com.atlassian.jira.toolkit"; //$NON-NLS-1$

}

==> org.eclipse.mylyn.jira.core.source_3.3.2.v20100222-0100-e3x.jar: org/eclipse/mylyn/internal/jira/core/IJiraConstants.java <==
/*******************************************************************************
 * Copyright (c) 2004, 2009 Tasktop Technologies and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Tasktop Technologies - initial API and implementation
 *******************************************************************************/

package org.eclipse.mylyn.internal.jira.core;

public class IJiraConstants {

	public static final String ATTRIBUTE_TYPE = "attribute.jira.type"; //$NON-NLS-1$

	public static final String ATTRIBUTE_ISSUE_PARENT_KEY = "attribute.jira.issue_parent_key"; //$NON-NLS-1$

	public static final String ATTRIBUTE_ISSUE_PARENT_ID = "attribute.jira.issue_parent_id"; //$NON-NLS-1$

	public static final String ATTRIBUTE_ENVIRONMENT = "attribute.jira.environment"; //$NON-NLS-1$

	public static final String ATTRIBUTE_COMPONENTS = "attribute.jira.components"; //$NON-NLS-1$

	public static final String ATTRIBUTE_FIXVERSIONS = "attribute.jira.fixversions"; //$NON-NLS-1$

	public static final String ATTRIBUTE_AFFECTSVERSIONS = "attribute.jira.affectsversions"; //$NON-NLS-1$

	public static final String ATTRIBUTE_ESTIMATE = "attribute.jira.estimate"; //$NON-NLS-1$

	public static final String ATTRIBUTE_INITIAL_ESTIMATE = "attribute.jira.initialestimate"; //$NON-NLS-1$

	public static final String ATTRIBUTE_ACTUAL = "attribute.jira.actual"; //$NON-NLS-1$

	public static final String ATTRIBUTE_DUE_DATE = "attribute.jira.due"; //$NON-NLS-1$

	public static final String ATTRIBUTE_SUBTASK_IDS = "attribute.jira.subtask_ids"; //$NON-NLS-1$

	public static final String ATTRIBUTE_SUBTASK_KEYS = "attribute.jira.subtask_keys"; //$NON-NLS-1$

	public static final String ATTRIBUTE_CUSTOM_PREFIX = "attribute.jira.custom::"; //$NON-NLS-1$

	public static final String ATTRIBUTE_LINK_PREFIX = "attribute.jira.link::"; //$NON-NLS-1$

	public static final String ATTRIBUTE_SECURITY_LEVEL = "attribute.jira.security"; //$NON-NLS-1$

	public static final String ATTRIBUTE_READ_ONLY = "attribute.jira.read-only"; //$NON-NLS-1$

	public static final String ATTRIBUTE_WORKLOG_NOT_SUPPORTED = "attribute.jira.worklog-not-supported"; //$NON-NLS-1$

	public static final String JIRA_DATE_FORMAT = "dd MMM yyyy HH:mm:ss z"; //$NON-NLS-1$

	public static final String META_TYPE = "type"; //$NON-NLS-1$

	public static final String ATTRIBUTE_LINKED_IDS = "attribute.jira.link_ids"; //$NON-NLS-1$

	public static final String META_SUB_TASK_TYPE = "isSubtaskType"; //$NON-NLS-1$

	public static final String JIRA_TOOLKIT_PREFIX = "com.atlassian.jira.toolkit"; //$NON-NLS-1$

	public static final String ATTRIBUTE_PROJECT_ROLES = "attribute.jira.project-roles"; //$NON-NLS-1$

	public static final String NEW_COMMENT_VIEWABLE_BY_ALL = "All Users"; //$NON-NLS-1$

}
